==> openGion7.2.0.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GEA08S.sql <==
/****************************************************************************/
/* GEA08 ( 項目名称定義(ﾗﾍﾞﾙ) )                                             */
/*                                                                          */
/* Created : 2018/09/28 16:03:20                                            */
/****************************************************************************/

CREATE TABLE GEA08 (
   SYSTEM_ID        VARCHAR2 (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID   */
 , LANG             VARCHAR2 (    2 )                   NOT NULL            /*  20 言語     */
 , CLM              VARCHAR2 (   50 )                   NOT NULL            /*  30 項目     */
 , NAME_JA          VARCHAR2 (  200 )                                       /*  40 名称     */
 , SNAME            VARCHAR2 (   60 )                                       /*  50 名前(短) */
 , LNAME            VARCHAR2 (  500 )                                       /*  60 名前(長) */
 , DESCRIPTION      VARCHAR2 ( 4000 )                                       /*  70 概要説明 */
 , KBLBL            VARCHAR2 (    1 )                   NOT NULL            /*  80 ﾗﾍﾞﾙ区分 */
 , COMMENTS         VARCHAR2 (  500 )                                       /*  90 ｺﾒﾝﾄ     */
 , CDKH             VARCHAR2 (    1 )                                       /* 100 改廃ｺｰﾄﾞ */
 , FGLOAD           VARCHAR2 (    1 )       DEFAULT '0' NOT NULL            /* 110 読込F    */
 , KBSAKU           VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 120 作成区分 */
 , RELEASE_NOTES    VARCHAR2 (  120 )                                       /* 130 ﾘﾘｰｽﾉｰﾄ  */
 , RDC_CODE         VARCHAR2 (   20 )                                       /* 190 設変番号 */
 , UNIQ             NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ              VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET            VARCHAR2 (   14 )                                       /* 820 登録日時 */
 , PGSET            VARCHAR2 (   10 )                                       /* 830 作成PG   */
 , PGPSET           VARCHAR2 (   10 )                                       /* 840 作成親PG */
 , USRSET           VARCHAR2 (   10 )                                       /* 850 作成者   */
 , DYUPD            VARCHAR2 (   14 )                                       /* 860 更新日時 */
 , PGUPD            VARCHAR2 (   10 )                                       /* 870 更新PG   */
 , PGPUPD           VARCHAR2 (   10 )                                       /* 880 更新親PG */
 , USRUPD           VARCHAR2 (   10 )                                       /* 890 更新者   */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );


CREATE SEQUENCE GEA08S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;


CREATE OR REPLACE TRIGGER GEA08T00 
  BEFORE INSERT ON GEA08
  FOR EACH ROW 
  BEGIN 
    SELECT GEA08S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion7.2.9.5_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GEA08S.sql <==
/****************************************************************************/
/* GEA08 ( ﾗﾍﾞﾙ定義 )                                                       */
/*                                                                          */
/* Created : 2020/11/27 10:18:50                                            */
/****************************************************************************/

CREATE TABLE GEA08 (
   SYSTEM_ID        VARCHAR2 (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID   */
 , LANG             VARCHAR2 (    2 )                   NOT NULL            /*  20 言語     */
 , CLM              VARCHAR2 (   50 )                   NOT NULL            /*  30 項目     */
 , NAME_JA          VARCHAR2 (  200 )                                       /*  40 名称     */
 , SNAME            VARCHAR2 (  200 )                                       /*  50 名前(短) */
 , LNAME            VARCHAR2 (  500 )                                       /*  60 名前(長) */
 , DESCRIPTION      VARCHAR2 ( 4000 )                                       /*  70 概要説明 */
 , KBLBL            VARCHAR2 (    1 )                   NOT NULL            /*  80 ﾗﾍﾞﾙ区分 */
 , COMMENTS         VARCHAR2 (  500 )                                       /*  90 ｺﾒﾝﾄ     */
 , CDKH             VARCHAR2 (    1 )                                       /* 100 改廃ｺｰﾄﾞ */
 , FGLOAD           VARCHAR2 (    1 )       DEFAULT '0' NOT NULL            /* 110 読込F    */
 , KBSAKU           VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 120 作成区分 */
 , RELEASE_NOTES    VARCHAR2 (  120 )                                       /* 130 ﾘﾘｰｽﾉｰﾄ  */
 , RDC_CODE         VARCHAR2 (   20 )                                       /* 190 設変番号 */
 , UNIQ             NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ              VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET            VARCHAR2 (   14 )                                       /* 820 作成日時 */
 , PGSET            VARCHAR2 (   10 )                                       /* 830 作成PG   */
 , PGPSET           VARCHAR2 (   10 )                                       /* 840 作成親PG */
 , USRSET           VARCHAR2 (   10 )                                       /* 850 作成者   */
 , DYUPD            VARCHAR2 (   14 )                                       /* 860 更新日時 */
 , PGUPD            VARCHAR2 (   10 )                                       /* 870 更新PG   */
 , PGPUPD           VARCHAR2 (   10 )                                       /* 880 更新親PG */
 , USRUPD           VARCHAR2 (   10 )                                       /* 890 更新者   */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );


CREATE SEQUENCE GEA08S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;


CREATE OR REPLACE TRIGGER GEA08T00 
  BEFORE INSERT ON GEA08
  FOR EACH ROW 
  BEGIN 
    SELECT GEA08S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
